// Copyright (c) 2016, root ext. All rights reserved. Use of this source code
// is governed by a BSD-style license that can be found in the LICENSE file.

import '../lib/dna.dart';
import 'dart:io' as io;

@Struct()
class Process {
  @Field(ARG_INT, 0)
  int id;

  @Field(ARG_INT, 1)
  int parentId;
}

@Lib('libc.so.6')
class Libc {
  dynamic lib = new DynamicLibrary<Libc>();

  int getpid() { return lib.getpid(); }
  int getuid() { return lib.getuid(); }
  int getgid() { return lib.getgid(); }

  @Arg(ARG_INT)
  int getgroups (int count, @Arg(ARG_LISTINT) Ref<List<int>> groups) { return lib.getgroups(count, groups); }

  int rand() { return lib.rand(); }
  int rand_r(@Arg(ARG_POINTER) Ref<int> seedp) { return lib.rand_r(seedp); }
  void srand(@Arg(ARG_INT) int seed) { return lib.srand(seed); }
}

void main(){
  Libc libc = new Libc();
  var processId = libc.getpid();
  print('pid $processId = ${io.pid}');

  var userId = libc.getuid();
  print('userId ${userId}');

  var groupId = libc.getgid();
  print('groupId ${groupId}');

  var n = libc.getgroups(0, new Ref(new List()));
  var groups = new Ref<List<int>>(new List<int>(n));
  libc.getgroups(n, groups);
  print('groups ${groups.value}');

  libc.srand(0xDEADBEEF);
  var rand = libc.rand();
  print('rand $rand');

  Ref<int> seed = new Ref<int>(0xDEADBEEF);
  var srand = libc.rand_r(seed);
  print('rand with seed $srand');

}
